Function akka_projection_rs::consumer_filter::exclude_all
source · pub fn exclude_all() -> FilterCriteriaExpand description
Exclude events from all entity ids, convenience for combining with for example a topic filter to include only events matching the topic filter.